#
# spec file for package growlight
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %{ix86} %{arm}
%bcond_with  pandoc
%else
%bcond_without  pandoc
%endif
Name:           growlight
Version:        1.2.38
Release:        1.14
Summary:        Disk manipulation and system setup tool
License:        GPL-3.0-or-later
Group:          System/Monitoring
URL:            https://nick-black.com/dankwiki/index.php/Growlight
Source:         https://github.com/dankamongmen/growlight/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
%if %{with pandoc}
BuildRequires:  pandoc
%endif
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(blkid) >= 2.20.1
BuildRequires:  pkgconfig(devmapper) >= 1.02.74
BuildRequires:  pkgconfig(doctest) >= 2.3.5
BuildRequires:  pkgconfig(libatasmart) >= 0.19
BuildRequires:  pkgconfig(libcap) >= 2.24
BuildRequires:  pkgconfig(libcryptsetup) >= 2.0.2
BuildRequires:  pkgconfig(libpci) >= 3.1.9
BuildRequires:  pkgconfig(libudev) >= 175
BuildRequires:  pkgconfig(nettle) >= 3.5.1
BuildRequires:  pkgconfig(notcurses) >= 2.4.4
BuildRequires:  pkgconfig(pciaccess) >= 0.13.1
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(zlib) >= 1.2.11
Recommends:     btrfsprogs
Recommends:     dosfstools
Recommends:     e2fsprogs
Recommends:     f2fs-tools
Recommends:     hdparm
Recommends:     hfsutils
Recommends:     ipmctl
Recommends:     mdadm
Recommends:     ntfs-3g
Recommends:     nvme-cli
Recommends:     xfsprogs

%description
growlight can manipulate both physical (NVMe, SATA, etc.) and virtual (mdadm,
device-mapper, etc.) block devices, help identify bottlenecks in a storage
topology, create and destroy filesystems, and prepare a machine for initial
boot when run in an installer context. Both full-screen and REPL readline UIs
are available.

%prep
%setup -q

%build
%cmake -DUSE_LIBZFS=OFF -DUSE_PANDOC=%{with pandoc}
%make_build

%install
%cmake_install

%files
%license COPYING
%doc README.md
%{_sbindir}/growlight
%{_sbindir}/growlight-readline
%dir %{_datadir}/growlight
%{_datadir}/growlight/growlight.jpg
%if %{with pandoc}
%{_mandir}/man8/growlight-readline.8%{?ext_man}
%{_mandir}/man8/growlight.8%{?ext_man}
%endif

%changelog
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.38:
  * don't print misleading diagnostic when exiting with failure
  * growlight: ignore NCTYPE_RELEASE
  * adapting notcurses
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.37
  * [readline] always create an ncdirect #151
  * growlight-readline: version: display image on left
  * growlight-readline: recognize exit as synonym for quit
- Update to version 1.2.36
  * [notcursesui] clear out some reverse video #148
  * [ifaces] set background default when not selected
  * remove all readline, use notcurses 2.4.4 #149
  * stop using NCSTYLE_REVERSE
  * [CMake] require notcurses 2.4.0+
  * zfs: fix for gcc7 fallthrough attribute syntax
* Fri Aug 20 2021 Martin Hauke <mardnh@gmx.de>
- Udpate to version 1.2.35
  * Updated for Notcurses 2.3.9
  * Fix build failures
* Thu May 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.33
  * Upstream does not provide a changelog
* Thu Apr  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.32
  * Upstream does not provide a changelog
- Drop patch (fixed upstream):
  * 0001-tests-fix-alignment-of-packed-fields-141.patch
* Tue Apr  6 2021 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-tests-fix-alignment-of-packed-fields-141.patch
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.31
  * Upstream does not provide a changelog
* Sat Feb 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.28
  * Upstream does not provide a changelog
* Tue Jan 19 2021 Dirk Müller <dmueller@suse.com>
- build without pandoc on 32bit platforms
* Sun Jan 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.27
  * Upstream does not provide a changelog
* Sun Dec  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.23
  * Upstream does not provide a changelog
* Sun Nov  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.18
  * use recursive_lock_init() for musl.
  * add recursive_lock_init() for glibc+musl.
  * convert growlight.png to growlight.jpeg, save ~130K
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.17
  * purge glibc version lookup to work on musl.
  * remove pre-2.0.1 notcurses compat code.
  * CMake: require notcurses 2.0.1+.
* Mon Oct 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.16
  * build system fixes
  * enforce requirement of Notcurses 2.0.0+
  * purge notcurses_version_check()
  * redraw details border from update_details()
  * extract out subdisplay_border()
  * ATA serial numbers can be 20 octets, not 10
  * sg: reference 'ATA Command Pass-Through' spec
  * color bottom border of selected blockdev to match sides
- Update to version 1.2.15
  * kill 'REVERSE', fix up bottom border reverse
  * repair disappearing write-cache/alignment details
  * add most menu items
  * handle_input: execute menu mouse clicks
  * handle_input: don't print warning on wayward mouse clicks
  * use correct shortcuts for menu items partition table/filesystem
    create.
  * resize: take menu+footer into account
  * color menu internals + make them opaque
  * support mouse, get menu unrolling
  * create a menu
  * remove duplicate handling of Ctrl+L
  * lock down SIGWINCH early to ensure we see NCKEY_RESIZE
  * handle ctrl+L and NCKEY_RESIZE
* Sat Oct 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.14
  * require notcurses 1.7.6
  * pass NCDIRECT_OPTION_INHIBIT_CBREAK
  * use crc32 from zlib
  * CMake: depend on libz 1.2.11+
  * readline: call ncdirect_stop() on all exit paths
  * Properly draw adapters truncated at the top
* Tue Sep 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.13
  - Adapt to notcurses 1.7.5 APIs
* Wed Sep  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.11
  * properly install manpages
* Wed Sep  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.10
  * man pages: switch to pandoc
- Drop patches
  * set-docbook-xsl-stylesheet-path.patch (not longer needed)
* Sun Aug 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.9
  * Upstream does not provide a changelog
- Drop patches:
  * 0002-require-notcurses-1.6.7.patch
  * 0003-notcurses-supply-NCOPTION_INHIBIT_SETLOCALE.patch
  * 0004-CMake-adapt-to-notcurses-1.6.12-ncreel-changes.patch
  * 0005-s-cliptop-drawfromtop-g.patch
  * 0006-print_adapter_devs-get-dimensions.patch
  * 0009-CMake-use-FeatureSummary.patch
  * 0010-fix-up-adapter-geometry-85.patch
  * 0011-notcurses-restore-color-glorious-color-85.patch
  * 0012-drop-bevel_top-bevel_bottom.patch
  * 0013-drop-notcurses_cursor_enable.patch
* Thu Aug 27 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.2.8
